@@ -30,23 +30,26 @@ ggit_branch_type_get_type (void)
 }
 
 GType
-ggit_cap_flags_get_type (void)
+ggit_feature_flags_get_type (void)
 {
 	static GType the_type = 0;
 	
 	if (the_type == 0)
 	{
 		static const GFlagsValue values[] = {
-			{ GGIT_CAP_THREADS,
-			  "GGIT_CAP_THREADS",
+			{ GGIT_FEATURE_THREADS,
+			  "GGIT_FEATURE_THREADS",
 			  "threads" },
-			{ GGIT_CAP_HTTPS,
-			  "GGIT_CAP_HTTPS",
+			{ GGIT_FEATURE_HTTPS,
+			  "GGIT_FEATURE_HTTPS",
 			  "https" },
+			{ GGIT_FEATURE_SSH,
+			  "GGIT_FEATURE_SSH",
+			  "ssh" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_flags_register_static (
-				g_intern_static_string ("GgitCapFlags"),
+				g_intern_static_string ("GgitFeatureFlags"),
 				values);
 	}
 	return the_type;
@@ -306,9 +309,9 @@ ggit_diff_flag_get_type (void)
 			{ GGIT_DIFF_FLAG_NOT_BINARY,
 			  "GGIT_DIFF_FLAG_NOT_BINARY",
 			  "not-binary" },
-			{ GGIT_DIFF_FLAG_VALID_OID,
-			  "GGIT_DIFF_FLAG_VALID_OID",
-			  "valid-oid" },
+			{ GGIT_DIFF_FLAG_VALID_ID,
+			  "GGIT_DIFF_FLAG_VALID_ID",
+			  "valid-id" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_flags_register_static (
@@ -436,29 +439,29 @@ ggit_file_mode_get_type (void)
 }
 
 GType
-ggit_merge_automerge_mode_get_type (void)
+ggit_merge_file_favor_get_type (void)
 {
 	static GType the_type = 0;
 	
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ GGIT_MERGE_AUTOMERGE_MODE_NORMAL,
-			  "GGIT_MERGE_AUTOMERGE_MODE_NORMAL",
+			{ GGIT_MERGE_FILE_FAVOR_NORMAL,
+			  "GGIT_MERGE_FILE_FAVOR_NORMAL",
 			  "normal" },
-			{ GGIT_MERGE_AUTOMERGE_MODE_NONE,
-			  "GGIT_MERGE_AUTOMERGE_MODE_NONE",
-			  "none" },
-			{ GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS,
-			  "GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS",
-			  "favor-ours" },
-			{ GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS,
-			  "GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS",
-			  "favor-theirs" },
+			{ GGIT_MERGE_FILE_FAVOR_OURS,
+			  "GGIT_MERGE_FILE_FAVOR_OURS",
+			  "ours" },
+			{ GGIT_MERGE_FILE_FAVOR_THEIRS,
+			  "GGIT_MERGE_FILE_FAVOR_THEIRS",
+			  "theirs" },
+			{ GGIT_MERGE_FILE_FAVOR_UNION,
+			  "GGIT_MERGE_FILE_FAVOR_UNION",
+			  "union" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
-				g_intern_static_string ("GgitMergeAutomergeMode"),
+				g_intern_static_string ("GgitMergeFileFavor"),
 				values);
 	}
 	return the_type;
