@@ -13,8 +13,8 @@ G_BEGIN_DECLS
 #define GGIT_TYPE_BRANCH_TYPE	(ggit_branch_type_get_type())
 GType ggit_branch_type_get_type	(void) G_GNUC_CONST;
 
-#define GGIT_TYPE_CAP_FLAGS	(ggit_cap_flags_get_type())
-GType ggit_cap_flags_get_type	(void) G_GNUC_CONST;
+#define GGIT_TYPE_FEATURE_FLAGS	(ggit_feature_flags_get_type())
+GType ggit_feature_flags_get_type	(void) G_GNUC_CONST;
 
 #define GGIT_TYPE_BLAME_FLAGS	(ggit_blame_flags_get_type())
 GType ggit_blame_flags_get_type	(void) G_GNUC_CONST;
@@ -46,8 +46,8 @@ GType ggit_error_get_type	(void) G_GNUC_CONST;
 #define GGIT_TYPE_FILE_MODE	(ggit_file_mode_get_type())
 GType ggit_file_mode_get_type	(void) G_GNUC_CONST;
 
-#define GGIT_TYPE_MERGE_AUTOMERGE_MODE	(ggit_merge_automerge_mode_get_type())
-GType ggit_merge_automerge_mode_get_type	(void) G_GNUC_CONST;
+#define GGIT_TYPE_MERGE_FILE_FAVOR	(ggit_merge_file_favor_get_type())
+GType ggit_merge_file_favor_get_type	(void) G_GNUC_CONST;
 
 #define GGIT_TYPE_MERGE_TREE_FLAGS	(ggit_merge_tree_flags_get_type())
 GType ggit_merge_tree_flags_get_type	(void) G_GNUC_CONST;
