@@ -81,15 +81,21 @@ GgitRepository *ggit_ref_get_owner          (GgitRef        *ref);
 
 GgitRef        *ggit_ref_set_symbolic_target(GgitRef        *ref,
                                              const gchar    *target,
+                                             GgitSignature  *signature,
+                                             const gchar    *log_message,
                                              GError        **error);
 
 GgitRef        *ggit_ref_set_target         (GgitRef        *ref,
                                              GgitOId        *oid,
+                                             GgitSignature  *signature,
+                                             const gchar    *log_message,
                                              GError        **error);
 
 GgitRef        *ggit_ref_rename             (GgitRef        *ref,
                                              const gchar    *new_name,
                                              gboolean        force,
+                                             GgitSignature  *signature,
+                                             const gchar    *log_message,
                                              GError        **error);
 
 void            ggit_ref_delete             (GgitRef        *ref,
@@ -98,8 +104,6 @@ void            ggit_ref_delete             (GgitRef        *ref,
 GgitObject     *ggit_ref_lookup             (GgitRef        *ref,
                                              GError        **error);
 
-gboolean        ggit_ref_has_reflog         (GgitRef        *ref);
-
 GgitReflog     *ggit_ref_get_reflog         (GgitRef        *ref,
                                              GError        **error);
 
