@@ -30,8 +30,9 @@
 ASSERT_ENUM (GGIT_BRANCH_LOCAL,  GIT_BRANCH_LOCAL);
 ASSERT_ENUM (GGIT_BRANCH_REMOTE, GIT_BRANCH_REMOTE);
 
-ASSERT_ENUM (GGIT_CAP_THREADS, GIT_CAP_THREADS);
-ASSERT_ENUM (GGIT_CAP_HTTPS,   GIT_CAP_HTTPS);
+ASSERT_ENUM (GGIT_FEATURE_THREADS, GIT_FEATURE_THREADS);
+ASSERT_ENUM (GGIT_FEATURE_HTTPS,   GIT_FEATURE_HTTPS);
+ASSERT_ENUM (GGIT_FEATURE_SSH,     GIT_FEATURE_SSH);
 
 ASSERT_ENUM (GGIT_CONFIG_LEVEL_SYSTEM, GIT_CONFIG_LEVEL_SYSTEM);
 ASSERT_ENUM (GGIT_CONFIG_LEVEL_XDG, GIT_CONFIG_LEVEL_XDG);
@@ -80,7 +81,7 @@ ASSERT_ENUM (GGIT_DIFF_SHOW_UNMODIFIED,            GIT_DIFF_SHOW_UNMODIFIED);
 ASSERT_ENUM (GGIT_DIFF_PATIENCE,                   GIT_DIFF_PATIENCE);
 ASSERT_ENUM (GGIT_DIFF_MINIMAL,                    GIT_DIFF_MINIMAL);
 
-ASSERT_ENUM (GGIT_DIFF_FLAG_VALID_OID,  GIT_DIFF_FLAG_VALID_OID);
+ASSERT_ENUM (GGIT_DIFF_FLAG_VALID_ID,   GIT_DIFF_FLAG_VALID_ID);
 ASSERT_ENUM (GGIT_DIFF_FLAG_BINARY,     GIT_DIFF_FLAG_BINARY);
 ASSERT_ENUM (GGIT_DIFF_FLAG_NOT_BINARY, GIT_DIFF_FLAG_NOT_BINARY);
 
@@ -111,10 +112,10 @@ ASSERT_ENUM (GGIT_FILE_MODE_BLOB_EXECUTABLE, GIT_FILEMODE_BLOB_EXECUTABLE);
 ASSERT_ENUM (GGIT_FILE_MODE_LINK, GIT_FILEMODE_LINK);
 ASSERT_ENUM (GGIT_FILE_MODE_COMMIT, GIT_FILEMODE_COMMIT);
 
-ASSERT_ENUM (GGIT_MERGE_AUTOMERGE_MODE_NORMAL, GIT_MERGE_AUTOMERGE_NORMAL);
-ASSERT_ENUM (GGIT_MERGE_AUTOMERGE_MODE_NONE, GIT_MERGE_AUTOMERGE_NONE);
-ASSERT_ENUM (GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS, GIT_MERGE_AUTOMERGE_FAVOR_OURS);
-ASSERT_ENUM (GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS, GIT_MERGE_AUTOMERGE_FAVOR_THEIRS);
+ASSERT_ENUM (GGIT_MERGE_FILE_FAVOR_NORMAL, GIT_MERGE_FILE_FAVOR_NORMAL);
+ASSERT_ENUM (GGIT_MERGE_FILE_FAVOR_OURS, GIT_MERGE_FILE_FAVOR_OURS);
+ASSERT_ENUM (GGIT_MERGE_FILE_FAVOR_THEIRS, GIT_MERGE_FILE_FAVOR_THEIRS);
+ASSERT_ENUM (GGIT_MERGE_FILE_FAVOR_UNION, GIT_MERGE_FILE_FAVOR_UNION);
 
 ASSERT_ENUM (GGIT_MERGE_TREE_FIND_RENAMES, GIT_MERGE_TREE_FIND_RENAMES);
 
