@@ -201,11 +201,11 @@ typedef struct _GgitIndexEntriesResolveUndo GgitIndexEntriesResolveUndo;
 typedef struct _GgitIndexEntryResolveUndo GgitIndexEntryResolveUndo;
 
 /**
- * GgitMergeTreeOptions:
+ * GgitMergeOptions:
  *
  * Represents the options used when merging.
  */
-typedef struct _GgitMergeTreeOptions GgitMergeTreeOptions;
+typedef struct _GgitMergeOptions GgitMergeOptions;
 
 /**
  * GgitNative:
@@ -398,9 +398,10 @@ typedef enum
 
 typedef enum
 {
-	GGIT_CAP_THREADS = 1 << 0,
-	GGIT_CAP_HTTPS   = 1 << 1
-} GgitCapFlags;
+	GGIT_FEATURE_THREADS = 1 << 0,
+	GGIT_FEATURE_HTTPS   = 1 << 1,
+	GGIT_FEATURE_SSH     = (1 << 2)
+} GgitFeatureFlags;
 
 
 /**
@@ -557,14 +558,14 @@ typedef enum {
  * GgitDiffFlag:
  * @GGIT_DIFF_FLAG_BINARY: if the file is binary.
  * @GGIT_DIFF_FLAG_NOT_BINARY: if the file is not binary.
- * @GGIT_DIFF_FLAG_VALID_OID: if the OID is valid.
+ * @GGIT_DIFF_FLAG_VALID_ID: if the ID is valid.
  *
  * Describes the diff file and/or delta flags
  */
 typedef enum {
 	GGIT_DIFF_FLAG_BINARY     = 1 << 0,
 	GGIT_DIFF_FLAG_NOT_BINARY = 1 << 1,
-	GGIT_DIFF_FLAG_VALID_OID  = 1 << 2
+	GGIT_DIFF_FLAG_VALID_ID   = 1 << 2
 } GgitDiffFlag;
 
 /**
@@ -633,17 +634,26 @@ typedef enum {
 /* NOTE: keep in sync with git2/merge.h */
 /**
  * GgitMergeAutomergeMode:
- * @GGIT_MERGE_AUTOMERGE_MODE_NORMAL:
- * @GGIT_MERGE_AUTOMERGE_MODE_NONE:
- * @GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS:
- * @GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS:
+ * @GGIT_MERGE_FILE_FAVOR_NORMAL: When a region of a file is changed in both branches,
+ * a conflict will be recorded in the index so that `git_checkout` can produce
+ * a merge file with conflict markers in the working directory. This is the default.
+ * @GGIT_MERGE_FILE_FAVOR_OURS: When a region of a file is changed in both branches, the file
+ * created in the index will contain the "ours" side of any conflicting
+ * region. The index will not record a conflict.
+ * @GGIT_MERGE_FILE_FAVOR_THEIRS: When a region of a file is changed in both branches, the file
+ * created in the index will contain the "theirs" side of any conflicting
+ * region. The index will not record a conflict.
+ * @GGIT_MERGE_FILE_FAVOR_UNION: When a region of a file is changed in both branches, the file
+ * created in the index will contain each unique line from each side,
+ * which has the result of combining both files.  The index will not
+ * record a conflict.
  */
 typedef enum {
-	GGIT_MERGE_AUTOMERGE_MODE_NORMAL       = 0,
-	GGIT_MERGE_AUTOMERGE_MODE_NONE         = 1,
-	GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS   = 2,
-	GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS = 3
-} GgitMergeAutomergeMode;
+	GGIT_MERGE_FILE_FAVOR_NORMAL = 0,
+	GGIT_MERGE_FILE_FAVOR_OURS   = 1,
+	GGIT_MERGE_FILE_FAVOR_THEIRS = 2,
+	GGIT_MERGE_FILE_FAVOR_UNION  = 3
+} GgitMergeFileFavor;
 
 /**
  * GgitMergeTreeFlags:
