@@ -23,36 +23,41 @@
 
 #include <libgit2-glib/ggit-blob.h>
 #include <libgit2-glib/ggit-blob-output-stream.h>
+#include <libgit2-glib/ggit-branch-enumerator.h>
 #include <libgit2-glib/ggit-branch.h>
 #include <libgit2-glib/ggit-clone-options.h>
 #include <libgit2-glib/ggit-commit.h>
-#include <libgit2-glib/ggit-config.h>
 #include <libgit2-glib/ggit-config-entry.h>
+#include <libgit2-glib/ggit-config.h>
 #include <libgit2-glib/ggit-cred.h>
 #include <libgit2-glib/ggit-cred-plaintext.h>
-#include <libgit2-glib/ggit-diff-list.h>
 #include <libgit2-glib/ggit-diff-delta.h>
 #include <libgit2-glib/ggit-diff-file.h>
+#include <libgit2-glib/ggit-diff.h>
+#include <libgit2-glib/ggit-diff-hunk.h>
+#include <libgit2-glib/ggit-diff-line.h>
 #include <libgit2-glib/ggit-diff-options.h>
-#include <libgit2-glib/ggit-diff-patch.h>
-#include <libgit2-glib/ggit-diff-range.h>
+#include <libgit2-glib/ggit-diff-similarity-metric.h>
 #include <libgit2-glib/ggit-enum-types.h>
 #include <libgit2-glib/ggit-error.h>
-#include <libgit2-glib/ggit-index.h>
 #include <libgit2-glib/ggit-index-entry.h>
 #include <libgit2-glib/ggit-index-entry-resolve-undo.h>
+#include <libgit2-glib/ggit-index.h>
 #include <libgit2-glib/ggit-main.h>
-#include <libgit2-glib/ggit-merge-tree-options.h>
+#include <libgit2-glib/ggit-merge-options.h>
+#include <libgit2-glib/ggit-message.h>
 #include <libgit2-glib/ggit-native.h>
-#include <libgit2-glib/ggit-object.h>
-#include <libgit2-glib/ggit-object-factory.h>
 #include <libgit2-glib/ggit-object-factory-base.h>
+#include <libgit2-glib/ggit-object-factory.h>
+#include <libgit2-glib/ggit-object.h>
 #include <libgit2-glib/ggit-oid.h>
+#include <libgit2-glib/ggit-patch.h>
 #include <libgit2-glib/ggit-push.h>
 #include <libgit2-glib/ggit-ref.h>
-#include <libgit2-glib/ggit-ref-spec.h>
-#include <libgit2-glib/ggit-reflog.h>
 #include <libgit2-glib/ggit-reflog-entry.h>
+#include <libgit2-glib/ggit-reflog.h>
+#include <libgit2-glib/ggit-ref-spec.h>
+#include <libgit2-glib/ggit-remote-callbacks.h>
 #include <libgit2-glib/ggit-remote.h>
 #include <libgit2-glib/ggit-repository.h>
 #include <libgit2-glib/ggit-revision-walker.h>
@@ -61,9 +66,9 @@
 #include <libgit2-glib/ggit-submodule.h>
 #include <libgit2-glib/ggit-tag.h>
 #include <libgit2-glib/ggit-transfer-progress.h>
-#include <libgit2-glib/ggit-tree.h>
 #include <libgit2-glib/ggit-tree-builder.h>
 #include <libgit2-glib/ggit-tree-entry.h>
+#include <libgit2-glib/ggit-tree.h>
 #include <libgit2-glib/ggit-types.h>
 
 #endif
